Primary author:

* `Ben Lopatin <https://github.com/bennylope>`_

Contributors:

* `Sebastian Annies <https://github.com/sannies>`_
* `Paul Backhouse <https://github.com/powlo>`_
* `Phil McMahon <https://github.com/philmcmahon>`_
* `Aaron Krill <https://github.com/krillr>`_
* `Mauricio de Abreu Antunes <https://github.com/mauricioabreu>`_
* `Omer Katz <https://github.com/thedrow>`_
* `Andrew Velis <https://github.com/avelis>`_
* `Tom Davis <https://github.com/tdavis>`_
* `Nicolas Noirbent <https://github.com/noirbee>`_
* `Samuel Bishop <https://github.com/techdragon>`_
* `Eric Amador <https://github.com/amadornimbis>`_
* `Jon Miller <https://github.com/jondelmil>`_
* `Robert Christopher <https://github.com/RobertChristopher>`_
* `Basil Shubin <https://github.com/bashu>`_
* `Federico Capoano <https://github.com/nemesisdesign>`_
* `Justin Mayer <https://github.com/justinmayer>`_
* `Alan Zhu <https://github.com/AZtheAsian>`_
* `Samuel Spencer <https://github.com/LegoStormtroopr>`_
* `Seb Vetter <https://github.com/elbaschid>`_
* `KimSia Sim <https://github.com/simkimsia>`_
* `Dan Moore <https://github.com/mgrdcm>`_

If your name is missing as a contributor that's my oversight, let me know at
ben@benlopatin.com
